@@ -3,7 +3,7 @@ package Finance::CoinbasePro::API::CLI::Fill
 
 use strict;
 use warnings;
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 use Mouse;
 use Finance::CoinbasePro::API::CLI::Util::CurrencyUtil qw(format_currency);
@@ -107,7 +107,7 @@ user_id => "513378df5210ff660900002b",
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
-lib::::Finance::CoinbasePro::API::CLI::Fill - lib::::Finance::CoinbasePro::API::CLI::Fill
+Finance::CoinbasePro::API::CLI::Fill - Finance::CoinbasePro::API::CLI::Fill
 
 
 =head1 DESCRIPTION
